@@ -11,11 +11,14 @@ class FlaviusBase:
     """
     FlaviusのAPIを取り扱うための基底クラス
     """
+    endpoint = conf.FLAVIUS_ENDPOINT
+    endpoint_dev = conf.FLAVIUS_ENDPOINT_DEV
+
     def __init__(self, search_url=None, create_url=None, update_url=None, delete_url=None):
-        url = conf.FLAVIUS_ENDPOINT
+        url = self.endpoint
         if settings.DEBUG:
             self.ssl_ctx = None
-            url = conf.FLAVIUS_ENDPOINT_DEV
+            url = self.endpoint_dev
         else:
             self.ssl_ctx = ssl.create_default_context()
             self.ssl_ctx.load_cert_chain(certfile=conf.FLAVIUS_CRT_FILE,
