@@ -42,6 +42,10 @@ class Settings:
     def FLAVIUS_API_ENVIRONMENT_SEARCH(self):
         return getattr(settings, "FLAVIUS_API_ENVIRONMENT_SEARCH", 'api/environment_fetch.php')
 
+    @property
+    def FLAVIUS_API_ENVIRONMENT_SET(self):
+        return getattr(settings, "FLAVIUS_API_ENVIRONMENT_SET", 'api/environment_set_value.php')
+
     @property
     def FLAVIUS_API_SORT_SEARCH(self):
         return getattr(settings, "FLAVIUS_API_SORT_SEARCH", 'api/sort_fetch_list.php')
